==> pointpos_api-0.0.13.tar.gz: lib/api/supplier_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/supplier.dart';

part 'supplier_api.jretro.dart';

@GenApiClient()
class SupplierApi extends ApiClient with _$SupplierApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    SupplierApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Supplier
    ///
    /// Create Supplier
    @PostReq(path: "/supplier", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Supplier> createSupplier(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Supplier body
        ) {
        return super.createSupplier(
        
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Supplier By ID
    ///
    /// Delete Supplier By ID
    @DeleteReq(path: "/supplier/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteSupplierByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.deleteSupplierByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Get Supplier List
    ///
    /// Get Supplier  List
    @GetReq(path: "/supplier", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Supplier>> findSupplier(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findSupplier(
        
        authorization, 
        
        xAPIKey
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Supplier By ID
    ///
    /// Get Supplier By ID
    @GetReq(path: "/supplier/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Supplier> getSupplierByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
        ) {
        return super.getSupplierByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ).timeout(timeout);
    }

    /// Update Supplier By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/supplier/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Supplier> updateSupplierByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey
            ,
             @AsJson() Supplier body
        ) {
        return super.updateSupplierByID(
        id
        ,
        authorization, 
        
        xAPIKey

        ,
        body
        ).timeout(timeout);
    }


}

==> pointpos_api-0.0.16.tar.gz: lib/api/supplier_api.dart <==
import 'package:jaguar_retrofit/annotations/annotations.dart';
import 'package:jaguar_retrofit/jaguar_retrofit.dart';
import 'package:jaguar_serializer/jaguar_serializer.dart';
import 'package:jaguar_mimetype/jaguar_mimetype.dart';
import 'dart:async';

import 'package:pointpos_api/model/exception.dart';
import 'package:pointpos_api/model/supplier.dart';

part 'supplier_api.jretro.dart';

@GenApiClient()
class SupplierApi extends ApiClient with _$SupplierApiClient {
    final Route base;
    final Map<String, CodecRepo> converters;
    final Duration timeout;

    SupplierApi({this.base, this.converters, this.timeout = const Duration(minutes: 2)});

    /// Create Supplier
    ///
    /// Create Supplier
    @PostReq(path: "/supplier", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Supplier> createSupplier(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Supplier body
        ) {
        return super.createSupplier(
        
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }

    /// Delete Supplier By ID
    ///
    /// Delete Supplier By ID
    @DeleteReq(path: "/supplier/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<void> deleteSupplierByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.deleteSupplierByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Get Supplier List
    ///
    /// Get Supplier  List
    @GetReq(path: "/supplier", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<List<Supplier>> findSupplier(
        
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ,
            @QueryParam("limit") num limit, 
        
            @QueryParam("offset") num offset, 
        
            @QueryParam("sort") String sort, 
        
            @QueryParam("direction") String direction, 
        
            @QueryParam("filter") List<String> filter
        ) {
        return super.findSupplier(
        
        authorization, 
        
        xAPIKey, 
        
        xPin
        ,
        limit, 
        
        offset, 
        
        sort, 
        
        direction, 
        
        filter

        ).timeout(timeout);
    }

    /// Get Supplier By ID
    ///
    /// Get Supplier By ID
    @GetReq(path: "/supplier/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Supplier> getSupplierByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
        ) {
        return super.getSupplierByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ).timeout(timeout);
    }

    /// Update Supplier By ID
    ///
    /// Update [object Object] By ID
    @PutReq(path: "/supplier/:id", metadata: {"auth": [ {"type": "apiKey", "name": "JWT", "keyName": "Authorization", "where": "header" }]})
    Future<Supplier> updateSupplierByID(
            @PathParam("id") String id
        ,
            @Header("Authorization") String authorization, 
        
            @Header("X-API-Key") String xAPIKey, 
        
            @Header("X-Pin") String xPin
            ,
             @AsJson() Supplier body
        ) {
        return super.updateSupplierByID(
        id
        ,
        authorization, 
        
        xAPIKey, 
        
        xPin

        ,
        body
        ).timeout(timeout);
    }


}
